@@ -19,8 +19,6 @@ import sys
 from os import path
 import os
 import re
-import random
-import string
 from calculate.install.distr import DistributiveError, IsoDistributive
 from calculate.install.variables.kernel import KernelConfig
 from calculate.lib.utils.common import getValueFromCmdLine
@@ -31,16 +29,17 @@ from calculate.lib.variables.system import RootType
 from .action import Actions
 from calculate.install import distr
 from calculate.lib.utils.device import getUdevDeviceInfo, humanreadableSize
-from calculate.lib.utils.files import isMount, process, typeFile, listDirectory, \
-    pathJoin, readFile
+from calculate.lib.utils.files import (isMount, process, typeFile,
+                                       listDirectory,
+                                       pathJoin, readFile, check_rw)
 from calculate.lib.utils.kernel import InitrdFile
 from calculate.lib.utils.tools import max_default
 from calculate.lib.utils.git import Git
 from ..build_storage import BuildStorage, Build
 from ..drive_spool import DriveSpool
 from .action import Actions as BuilderActions
-from calculate.lib.datavars import Variable, VariableError, ReadonlyVariable, \
-    TableVariable
+from calculate.lib.datavars import (Variable, VariableError, ReadonlyVariable,
+                                    TableVariable)
 from functools import wraps
 
 _ = lambda x: x
@@ -1347,8 +1346,7 @@ class VariableClBuilderLivemenuType(Variable):
             return "grub"
         elif root_type_ext in RootType.RebuildAvailable:
             return "flash"
-        else:
-            return ""
+        return "flash"
 
 
 class VariableClBuilderImageRepository(ReadonlyVariable):
@@ -1452,21 +1450,12 @@ class VariableClBuilderLivemenuPath(Variable):
                         root_type_ext not in RootType.IsoScanGrub:
             yield ("none", str(self.none_humanreadable))
 
-    def _random_string(self, l=10):
-        return "".join(
-            random.choice(string.ascii_letters) for i in xrange(0, l))
-
     def check_flash(self, value):
         try:
-            image = IsoDistributive(value)
-            d = image.getIsoContentDirectory()
-            mark_file = path.join(d, "_mark_%s" % self._random_string())
-            try:
-                open(mark_file, 'w')
-                os.unlink(mark_file)
-            except (OSError, IOError):
-                raise ValueError("Selected device is read-only")
-            image.close()
+            with IsoDistributive(value) as image:
+                d = image.getIsoContentDirectory()
+                if not check_rw(d):
+                    raise ValueError("Selected device is read-only")
         except DistributiveError as e:
             raise VariableError(str(e).strip())
 
